/*
 * iostat: report CPU and I/O statistics
 * (C) 1999 - Sebastien Godard <sebastien.godard@wanadoo.fr>
 */

#ifndef _IOSTAT_H
#define _IOSTAT_H

#define MIN(a, b) 	(((a) < (b)) ? (a) : (b))

/* Files */
#define STAT		"/proc/stat"


#define F_CPU		0x01
#define F_DISK		0x02
#define F_DISK_RBLK	0x04
#define F_DISK_WBLK	0x08
#define F_PAGE		0x10
#define F_TTY		0x20
#ifdef TTY
#define F_MASK		0x2f
#else
#define F_MASK		0x1f
#endif
#define F_DISK_PGIN	0x40
#define F_DISK_PGOUT	0x80

#define NR_DISK		4

#define DIGITS		"0123456789"

#define D_CPU_ONLY	1
#define D_DISK_ONLY	2
#define D_LOGICAL_IO	4
#define D_TIMESTAMP	8

#define DISPLAY_CPU_ONLY(m)	(((m) & D_CPU_ONLY) == D_CPU_ONLY)
#define DISPLAY_DISK_ONLY(m)	(((m) & D_DISK_ONLY) == D_DISK_ONLY)
#define DISPLAY_LOGICAL_IO(m)	(((m) & D_LOGICAL_IO) == D_LOGICAL_IO)
#define DISPLAY_TIMESTAMP(m)	(((m) & D_TIMESTAMP) == D_TIMESTAMP)

#define MAX_FILE_LEN	256

#define UTSNAME_LEN	65

/*
 * iostat file magic number:
 * will vary when file format changes
 */
#define IO_MAGIC	0x025b

#define BUF_SIZE	215
#define HEADER_SIZE	212
#define ENTRY_LONG_NB	3
#define ENTRY_INT_NB	26

#define IO_OFS_MAGIC	0
#define IO_OFS_DAY	2
#define IO_OFS_MONTH	3
#define IO_OFS_YEAR	4
#define IO_OFS_HOUR	5
#define IO_OFS_MIN	6
#define IO_OFS_SEC	7
#define IO_OFS_INTERVAL	8
#define IO_OFS_SYSNAME	16
#define IO_OFS_RELNAME	81
#define IO_OFS_NODENAME	146
#define IO_OFS_LONGSIZE	211


/*
 * Note: iostat file structure
 * 
 * bytes(dec)
 * ----------
 * 00-01: File magic number (LB-HB)
 * 02-02: Day (1-31)
 * 03-03: Month (0-11)
 * 04-04: Year (nb of years since 1900)
 * 05-05: Hour (24h format) (0-23)
 * 06-06: Minute (0-59)
 * 07-07: Second (0-59)
 * 08-15: Interval (long)
 * 16-80: System name (65 char max, null terminated)
 * 81-145:  Release number (id.)
 * 146-210: Node name (id.)
 * 211:   Size of long in bytes.
 * 212-...: Entry 1: CPU user (int)
 *                   CPU nice (int)
 *                   CPU system (int)
 *                   CPU wait (int)
 *                   CPU idle (long)
 *                   TTY in (long)
 *                   TTY out (long)
 *                   I/O tps (4*int)
 *                   I/O Blk_read (4*int)
 *                   I/O Blk_wrtn (4*int)
 *                   I/O total nb of Kb_read (int)
 *                   I/O total nb of Kb_wrtn (int)
 *                   I/O Kb_read (4*int)
 *                   I/O Kb_wrtn (4*int)
 */

/* Functions */
extern void get_localtime(struct tm *);
extern void close_files(int, int, int, int);
extern void open_files(char [], char [], int *, int *);
extern void print_gal_header(char *, char *, char *, char *);
extern int  next_slice(int);
extern void get_nb_proc_used(char *, int *);

#endif  /* _IOSTAT_H */
