/*
 * sar: report system activity
 * (C) 1999 - Sebastien Godard <sebastien.godard@wanadoo.fr>
 */

#ifndef _SAR_H
#define _SAR_H

#define MIN(a, b) 	(((a) < (b)) ? (a) : (b))

/* Define activities */
#define A_FORK		0x001
#define A_CTXSW		0x002
#define A_CPU		0x004
#define A_IRQ		0x008
#define A_PAGE		0x010
#define A_SWAP		0x020
#define A_IO		0x040
#define A_ONE_CPU	0x080
#define A_ONE_IRQ	0x100

#define GET_FORK(m)	(((m) & A_FORK) == A_FORK)
#define GET_CTXSW(m)	(((m) & A_CTXSW) == A_CTXSW)
#define GET_CPU(m)	(((m) & A_CPU) == A_CPU)
#define GET_IRQ(m)	(((m) & A_IRQ) == A_IRQ)
#define GET_PAGE(m)	(((m) & A_PAGE) == A_PAGE)
#define GET_SWAP(m)	(((m) & A_SWAP) == A_SWAP)
#define GET_IO(m)	(((m) & A_IO) == A_IO)
#define GET_ONE_CPU(m)	(((m) & A_ONE_CPU) == A_ONE_CPU)
#define GET_ONE_IRQ(m)	(((m) & A_ONE_IRQ) == A_ONE_IRQ)

/* Files */
#define STAT		"/proc/stat"
#define SA_DIR		"/var/log/sa"


/* Time must have the format HH:MM:SS with HH in 24-hour format */
#define DEF_TMSTART	"08:00:00"
#define DEF_TMEND	"18:00:00"

/*
 * CHECK SIZE WHENEVER NEW ACTIVITIES ARE ADDED!
 * (perhaps I should use dynamic allocation...
 */
#define MAX_LINE_LEN	6000   /* Must be enough for sar -A -I -2... */
#define MAX_FILE_LEN	256
#define BUF_SIZE	4000

#define NR_DISK		4
#define NR_IRQS		224
#define NR_CPUS		32
#define MAX_IRQS_DIV_8	32	/* Assume NR_IRQS <= 256 */
#define MAX_CPUS_DIV_8	32	/* Assume NR_CPUS <= 256 */

#define DIGITS		"0123456789"

#define UTSNAME_LEN	65

/* 
 * System activity daily file magic number
 * (will vary when file format changes)
 */
#define SA_MAGIC	0x015d

#define HEADER_SIZE	280

#define SA_OFS_MAGIC    0
#define SA_OFS_DAY      2
#define SA_OFS_MONTH    3
#define SA_OFS_YEAR     4
#define SA_OFS_HOUR     5
#define SA_OFS_MIN      6
#define SA_OFS_SEC      7
#define SA_OFS_ACTFLAG  8
#define SA_OFS_PROC     10
#define SA_OFS_IRQ      42
#define SA_OFS_ENTSZ    74
#define SA_OFS_INTERVAL 76
#define SA_OFS_SYSNAME	84
#define SA_OFS_RELNAME	149
#define SA_OFS_NODENAME	214
#define SA_OFS_LONGSIZE	279

/*
 * Note: system activity file structure
 * 
 * bytes(dec)
 * ----------
 * 00-01: File magic number (LB-HB)
 * 02-02: Day (1-31)
 * 03-03: Month (0-11)
 * 04-04: Year (nb of years since 1900) 
 * 05-05: Hour (24h-format) (0-23)
 * 06-06: Minute (0-59)
 * 07-07: Second (0-59)
 * 08-09: Activities
 *        08: bit 0: A_FORK
 *            bit 1: A_CTXSW
 *            bit 2: A_CPU
 *            bit 3: A_INT
 *            bit 4: A_PAGE
 *            bit 5: A_SWAP
 *            bit 6: A_IO
 *            bit 7: reserved
 *        09: Reserved
 * 10-41: Processors
 *        10: bit 0: Processor 0
 *            bit 1: Processor 1
 *        ... ...
 *        41: bit 7: Processor 255
 * 42-73: IRQ
 *        42: bit 0: IRQ 0
 *            bit 1: IRQ 1
 *        ... ...
 *        73: bit 7: IRQ 255
 * 74-75:   Entry size (LB-HB)
 * 76-83:   Interval (long)
 * 84-148:  System name (65 char max, null terminated)
 * 149-213: Release number (id.)
 * 214-278: Node name (id.)
 * 279:     Size of long (in bytes)
 * 280-...: Entry 1 (binary data)
 */

/* Functions */
extern void get_localtime(struct tm *);
extern void close_files(int, int, int, int);
extern void open_files(char [], char [], int *, int *);
extern void print_gal_header(char *, char *, char *, char *);
extern int  next_slice(int);
extern void get_nb_proc_used(char *, int *);

#endif  /* _SAR_H */

